"""" Command line interface for the bot"""
import logging
import os
import sys

import click
import colorama
from pyfiglet import figlet_format
from termcolor import colored

project_dir = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(project_dir)

colorama.init()
logging.basicConfig(level=logging.DEBUG, format='%(message)s')


@click.command()
@click.option('--poll', is_flag=True, help='Start the bot')
@click.option('--crawl', is_flag=True, help='Start the bot')
@click.option('--start', is_flag=True, help='Start the bot')
def handle_commands(poll, crawl, start):
    """Main method for handling commands through CLI"""
    if not os.environ.get('HOAX_DATA_PATH') or not os.environ.get('BOT_TOKEN'):
        stdout("ERROR: please set HOAX_DATA_PATH and BOT_TOKEN to start the bot! ", color="red")
        sys.exit(1)
    stdout("\nTabayyun Bot", color="blue", figlet_flag=True)
    if poll:
        stdout("Starting polling messages...", color="green")
        try:
            from src.view import telegram_bot
            telegram_bot.start_bot()
            stdout("Server completed", color="green")
        except Exception as exc:
            stdout("Starting server failed! : {}".format(exc), color="red")

    if crawl:
        stdout("Crawling news...", color="green")
        try:
            from src.service import crawler
            crawler.start(os.environ.get('HOAX_DATA_PATH'))
            stdout("Crawling completed!", color="green")
        except Exception as exc:
            stdout("Crawling failed! : {}".format(exc), color="red")

    if start:
        if not os.environ.get('WEBHOOK_URL'):
            stdout("ERROR: WEBHOOK_URL needs to be set for starting webhook server! ", color="red")
        if not os.environ.get('WEBHOOK_HOST'):
            stdout("WARNING: WEBHOOK_HOST is not set, set default value : 157.245.38.24", color="yellow")
        if not os.environ.get('WEBHOOK_PORT'):
            stdout("WARNING: WEBHOOK_PORT is not set, set default value : 8443", color="yellow")
        else:
            stdout(f"WEBHOOK_URL : {os.environ['WEBHOOK_URL']}", color="yellow")
        stdout("Starting Tabayyun webhook server...", color="green")
        try:
            from src.view import telegram_webhook
            #telegram_webhook.set_webhook()
            telegram_webhook.start()
        except Exception as exc:
            stdout("Starting server failed! : {}".format(exc), color="red")


def stdout(string: str, color: str, font: str = "slant", figlet_flag: bool = False):
    """ A helper method to print logs to stdout """
    if not figlet_flag:
        logging.info(colored(string, color))
    else:
        logging.info(colored(figlet_format(string, font=font), color))


if __name__ == "__main__":
    handle_commands()



from src.dataclasses.chat import Chat
from src.service.text_similarity import get_cosine_sim


class Server:
    """ The API server """

    def __init__(self):
        pass

    def start(self):
        pass

    def stop(self):
        pass

    @staticmethod
    def handler(chat: Chat):
        similarity = get_cosine_sim(chat.str_message)
        if similarity:
            status = similarity['status'].upper()
            link = "\n".join(similarity['link'])
        else:
            status = "Artikel tidak ditemukan".upper()
            link = "Not Found"
        content = chat.str_message if len(chat.str_message) < 1000 else f"{chat.str_message[:1000]}....(Sampai akhir)"
        reply = f"Konten : \n {content} \n\n Analisa : {status} \n\n Artikel terkait:\n {link}"
        return reply



import os
from src.lib.whatsapp import WhatsApp
driver_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), "../lib/bin")

os.environ["PATH"] += os.pathsep + driver_dir

whatsapp = WhatsApp(10)
print(whatsapp.send_message("Salam", ":heart: Good!"))


import os
import sys
from warnings import simplefilter

import pandas as pd
from sklearn.feature_extraction.text import CountVectorizer
from sklearn.metrics.pairwise import cosine_similarity

# ignore all future warnings
simplefilter(action='ignore', category=FutureWarning)
project_dir = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(project_dir)


def get_dataset(dataset_path: str):
    df = pd.read_csv(dataset_path, delimiter=";")
    return df


def get_vectors(text1, text2):
    vectorizer = CountVectorizer(text1, text2)
    vectorizer.fit([text1, text2])
    return vectorizer.transform([text1, text2]).toarray()


def get_cosine_sim(text: str):

    if os.environ.get('HOAX_DATA_PATH'):
        dataset_path = os.environ.get('HOAX_DATA_PATH')
    else:
        dataset_path = os.path.join(project_dir, "dataset/data.csv")
    ds = get_dataset(dataset_path)
    status = "ARTIKEL TIDAK DITEMUKAN"
    link = []
    for _, row in ds.iterrows():
        vectors_content = get_vectors(text.lower(), row['content'].lower())
        similarity_content = cosine_similarity(vectors_content)
        vectors_tittle = get_vectors(text.lower(), row['tittle'].lower())
        similarity_tittle = cosine_similarity(vectors_tittle)
        if similarity_tittle[0][1] > 0.70 or similarity_content[0][1] > 0.70:
            print(f"Similarity: {similarity_tittle[0][1]} {similarity_content[0][1]}")
            return {"status": row['status'], "link": [row['link']]}
        if text.lower() in row['content'].lower():
            status = "Ditemukan beberapa artikel terkait topik tersebut" \
                if len(set(link)) > 1 else "Ditemukan artikel terkait topik tersebut"
            link.append(f"{row['tittle']} - {row['link']}")

    return {"status": status, "link": set(link)}


if __name__ == '__main__':
    str1 = """Terdapat Sanksi Bagi yang Berkendara Malam di Jakarta"""
    print(get_cosine_sim(str1))
